@@ -19,7 +19,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 # road map of directory locations in GIF images
 my %gifMap = (
@@ -112,11 +112,11 @@ my %gifMap = (
 #          an output file was specified and a write error occurred
 sub ProcessGIF($$)
 {
-    my ($exifTool, $dirInfo) = @_;
+    my ($et, $dirInfo) = @_;
     my $outfile = $$dirInfo{OutFile};
     my $raf = $$dirInfo{RAF};
-    my $verbose = $exifTool->Options('Verbose');
-    my $out = $exifTool->Options('TextOut');
+    my $verbose = $et->Options('Verbose');
+    my $out = $et->Options('TextOut');
     my ($a, $s, $ch, $length, $buff);
     my ($err, $newComment, $setComment, $nvComment);
     my ($addDirs, %doneDir);
@@ -133,19 +133,19 @@ sub ProcessGIF($$)
     SetByteOrder('II');
 
     if ($outfile) {
-        $exifTool->InitWriteDirs(\%gifMap, 'XMP'); # make XMP the preferred group for GIF
-        $addDirs = $exifTool->{ADD_DIRS};
+        $et->InitWriteDirs(\%gifMap, 'XMP'); # make XMP the preferred group for GIF
+        $addDirs = $$et{ADD_DIRS};
         # determine if we are editing the File:Comment tag
-        my $delGroup = $exifTool->{DEL_GROUP};
-        $newComment = $exifTool->GetNewValues('Comment', \$nvComment);
+        my $delGroup = $$et{DEL_GROUP};
+        $newComment = $et->GetNewValues('Comment', \$nvComment);
         $setComment = 1 if $nvComment or $$delGroup{File};
         # change to GIF 89a if adding comment, XMP or ICC_Profile
         $buff = 'GIF89a' if $$addDirs{XMP} or $$addDirs{ICC_Profile} or defined $newComment;
         Write($outfile, $buff, $s) or $err = 1;
     } else {
-        $exifTool->SetFileType();   # set file type
-        $exifTool->HandleTag($tagTablePtr, 'GIFVersion', $ver);
-        $exifTool->HandleTag($tagTablePtr, 'ScreenDescriptor', $s);
+        $et->SetFileType();   # set file type
+        $et->HandleTag($tagTablePtr, 'GIFVersion', $ver);
+        $et->HandleTag($tagTablePtr, 'ScreenDescriptor', $s);
     }
     my $flags = Get8u(\$s, 4);
     if ($flags & 0x80) { # does this image contain a color table?
@@ -180,7 +180,7 @@ Block:
                 Write($outfile, "\0") or $err = 1;  # empty chunk as terminator
                 undef $newComment;
                 undef $nvComment;   # delete any other extraneous comments
-                ++$exifTool->{CHANGED};     # increment file changed flag
+                ++$$et{CHANGED};     # increment file changed flag
             }
             # add application extension containing XMP block if necessary
             # (this will place XMP before the first non-extension block)
@@ -190,7 +190,7 @@ Block:
                 my $xmpTable = GetTagTable('Image::ExifTool::XMP::Main');
                 my %dirInfo = ( Parent => 'GIF' );
                 $verbose and print $out "Creating XMP application extension block:\n";
-                $buff = $exifTool->WriteDirectory(\%dirInfo, $xmpTable);
+                $buff = $et->WriteDirectory(\%dirInfo, $xmpTable);
                 if (defined $buff and length $buff) {
                     my $lz = pack('C*',1,reverse(0..255),0);
                     Write($outfile, "\x21\xff\x0bXMP DataXMP", $buff, $lz) or $err = 1;
@@ -206,7 +206,7 @@ Block:
                 my $iccTable = GetTagTable('Image::ExifTool::ICC_Profile::Main');
                 my %dirInfo = ( Parent => 'GIF' );
                 $verbose and print $out "Creating ICC_Profile application extension block:\n";
-                $buff = $exifTool->WriteDirectory(\%dirInfo, $iccTable);
+                $buff = $et->WriteDirectory(\%dirInfo, $iccTable);
                 if (defined $buff and length $buff) {
                     my $pos = 0;
                     Write($outfile, "\x21\xff\x0bICCRGBG1012") or $err = 1;
@@ -276,7 +276,7 @@ Block:
             while ($length) {
                 last unless $raf->Read($buff, $length) == $length;
                 if ($verbose > 2 and not $outfile) {
-                    Image::ExifTool::HexDump(\$buff, undef, Out => $out);
+                    HexDump(\$buff, undef, Out => $out);
                 }
                 # add buffer to comment string
                 $comment .= $buff;
@@ -288,19 +288,19 @@ Block:
                 my $isOverwriting;
                 if ($setComment) {
                     if ($nvComment) {
-                        $isOverwriting = $exifTool->IsOverwriting($nvComment,$comment);
+                        $isOverwriting = $et->IsOverwriting($nvComment,$comment);
                         # get new comment again (may have been shifted)
-                        $newComment = $exifTool->GetNewValues($nvComment) if defined $newComment;
+                        $newComment = $et->GetNewValues($nvComment) if defined $newComment;
                     } else {
                         # group delete, or deleting additional comments after writing one
                         $isOverwriting = 1;
                     }
                 }
                 if ($isOverwriting) {
-                    ++$exifTool->{CHANGED};     # increment file changed flag
-                    $exifTool->VerboseValue('- Comment', $comment);
+                    ++$$et{CHANGED};     # increment file changed flag
+                    $et->VerboseValue('- Comment', $comment);
                     $comment = $newComment;
-                    $exifTool->VerboseValue('+ Comment', $comment) if defined $comment;
+                    $et->VerboseValue('+ Comment', $comment) if defined $comment;
                     undef $nvComment;   # just delete remaining comments
                 } else {
                     undef $setComment;  # leave remaining comments alone
@@ -323,10 +323,10 @@ Block:
                 undef $newComment;  # don't write the new comment again
             } else {
                 $rtnVal = 1;
-                $exifTool->FoundTag('Comment', $comment) if $comment;
+                $et->FoundTag('Comment', $comment) if $comment;
                 undef $comment;
                 # assume no more than one comment in FastScan mode
-                last if $exifTool->Options('FastScan');
+                last if $et->Options('FastScan');
             }
             next;
 
@@ -366,16 +366,16 @@ Block:
                 my $xmpTable = GetTagTable('Image::ExifTool::XMP::Main');
                 if ($outfile) {
                     if ($doneDir{XMP} and $doneDir{XMP} > 1) {
-                        $exifTool->Warn('Duplicate XMP block created');
+                        $et->Warn('Duplicate XMP block created');
                     }
-                    $buff = $exifTool->WriteDirectory(\%dirInfo, $xmpTable);
+                    $buff = $et->WriteDirectory(\%dirInfo, $xmpTable);
                     if (not defined $buff) {
                         # rewrite original XMP with landing zone (adding back null terminator)
                         Write($outfile, $hdr, $xmp, "\0") or $err = 1;
                         $doneDir{XMP} = 1;
                     } elsif (length $buff) {
                         if ($buff =~ /\0/) { # (check just to be safe)
-                            $exifTool->Error('XMP contained NULL character');
+                            $et->Error('XMP contained NULL character');
                         } else {
                             # write new XMP and landing zone
                             my $lz = pack('C*',1,reverse(0..255),0);
@@ -384,7 +384,7 @@ Block:
                         $doneDir{XMP} = 1;
                     } # else we are deleting the XMP
                 } else {
-                    $exifTool->ProcessDirectory(\%dirInfo, $xmpTable);
+                    $et->ProcessDirectory(\%dirInfo, $xmpTable);
                 }
                 next;
 
@@ -408,9 +408,9 @@ Block:
                 my $iccTable = GetTagTable('Image::ExifTool::ICC_Profile::Main');
                 if ($outfile) {
                     if ($doneDir{ICC_Profile} and $doneDir{ICC_Profile} > 1) {
-                        $exifTool->Warn('Duplicate ICC_Profile block created');
+                        $et->Warn('Duplicate ICC_Profile block created');
                     }
-                    $buff = $exifTool->WriteDirectory(\%dirInfo, $iccTable);
+                    $buff = $et->WriteDirectory(\%dirInfo, $iccTable);
                     # rewrite original ICC_Profile if nothing changed 
                     $buff = $icc_profile unless defined $buff;
                     if (length $buff) {
@@ -428,7 +428,7 @@ Block:
                         $doneDir{ICC_Profile} = 1;
                     } # else we are deleting the ICC profile
                 } else {
-                    $exifTool->ProcessDirectory(\%dirInfo, $iccTable);
+                    $et->ProcessDirectory(\%dirInfo, $iccTable);
                 }
                 next;
 
@@ -437,7 +437,7 @@ Block:
                 $raf->Read($buff, 5) == 5 or last;
                 # make sure this contains the expected data
                 if ($buff =~ /^\x03\x01(..)\0$/s) {
-                    $exifTool->HandleTag($tagTablePtr, 'ExtensionAnimation', $buff);
+                    $et->HandleTag($tagTablePtr, 'ExtensionAnimation', $buff);
                 }
                 $raf->Seek(-$length-5, 1) or last;  # seek back to start of block
 
@@ -473,7 +473,7 @@ Block:
                 $text .= $buff;
             }
             Write($outfile, "\0") or $err = 1 if $outfile;  # write terminator block
-            $exifTool->HandleTag($tagTablePtr, 'Text', $text);
+            $et->HandleTag($tagTablePtr, 'Text', $text);
             next;
         }
         Write($outfile, $ch, $s) or $err = 1 if $outfile;
@@ -487,8 +487,8 @@ Block:
         }
     }
     unless ($outfile) {
-        $exifTool->HandleTag($tagTablePtr, 'FrameCount', $frameCount) if $frameCount > 1;
-        $exifTool->HandleTag($tagTablePtr, 'Duration', $delayTime/100) if $delayTime;
+        $et->HandleTag($tagTablePtr, 'FrameCount', $frameCount) if $frameCount > 1;
+        $et->HandleTag($tagTablePtr, 'Duration', $delayTime/100) if $delayTime;
     }
 
     # set return value to -1 if we only had a write error
@@ -516,7 +516,7 @@ write GIF meta information.
 
 =head1 AUTHOR
 
-Copyright 2003-2013, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
